@@ -232,7 +232,11 @@ plot(ev, main="plot.evimp with various options",
     col.rss = "blue",
     lty.rss = 4,
     cex.legend = .8,
-    x.legend = "topright")
+    x.legend = "topright",
+    rh.col = "pink")
+
+a <- earth(Volume ~ Girth, data = trees)
+plot(evimp(a), main="plot.evimp with single var in model")
 
 cat('after calling evimp par("mar", "cex"):\n')
 print(par("mar", "cex"))
@@ -992,6 +996,7 @@ check.models.equal(m1, m2, "Force.xtx.prune test 2", check.subsets=FALSE)
 # TODO there appears to be a bug in leaps --- to see run the call below
 # with trace=4 and in the prune pass display note that at subset size 15
 # several terms are added and deleted -- but only one term should be added per step
+# Note added Apr 2013: Unable to reproduce.
 m1 <- earth(O3 ~ ., data = ozone1, nk=51, degree=2)
 m2 <- earth(O3 ~ ., data = ozone1, nk=51, degree=2, Force.xtx.prune=TRUE)
 check.models.equal(m1, m2, "Force.xtx.prune test 3", check.subsets=FALSE)
